@@ -137,14 +137,14 @@ macro_rules! plots {
 macro_rules! simple_fmt {
     ($data:expr,$title:expr,$xname:expr,$yname:expr) => {{
         let canvas = $crate::render::render_opt_builder().build();
-        let data = canvas.build_moved($data);
+        let data = $crate::render::Data::new($data, canvas);
         let (bx, by) = data.bounds();
         let xt = $crate::ticks::from_default(bx);
         let yt = $crate::ticks::from_default(by);
         data.plot_with($crate::plot_fmt($title, $xname, $yname, xt, yt))
     }};
     ($canvas:expr,$data:expr,$title:expr,$xname:expr,$yname:expr) => {{
-        let data = $canvas.build($data);
+        let data = $crate::render::Data::new($data, &$canvas);
         let (bx, by) = data.bounds();
         let xt = $crate::ticks::from_default(bx);
         let yt = $crate::ticks::from_default(by);
@@ -152,6 +152,20 @@ macro_rules! simple_fmt {
     }};
 }
 
+///
+/// Construct a [`Data`].
+///
+pub fn data<P: build::marker::PlotIteratorAndMarkers, K: Renderable>(
+    plots: P,
+    render: K,
+) -> Data<P::X, P::Y, P::Iter, K>
+where
+    P::X: PlotNum,
+    P::Y: PlotNum,
+{
+    render::Data::new(plots, render)
+}
+
 ///
 /// Leverage rust's display format system using [`std::cell::RefCell`] under the hood.
 ///
